@@ -1,5 +1,8 @@
 #!/usr/bin/python3
 #
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2011-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -55,7 +58,6 @@ import ldb
 import samba.getopt
 from samba.auth import system_session
 from univention import config_registry
-from samba import credentials
 
 
 parser = optparse.OptionParser("$prog [options] <host>")
@@ -75,7 +77,6 @@ parser.add_option("--modifysubnet", action="store_true", dest="modifysubnet")
 parser.add_option("--site", dest="site")
 parser.add_option("--sitelink", dest="sitelink")
 parser.add_option("--subnet", dest="subnet")
-parser.add_option("-A", "--authentication-file", dest="authentication_file", help="Get the credentials from a file")
 opts, args = parser.parse_args()
 
 if not opts.database_url:
@@ -104,11 +105,7 @@ if not (opts.createsitelink or opts.createsite or opts.createsubnet or opts.modi
 	parser.print_help()
 
 lp = sambaopts.get_loadparm()
-if opts.authentication_file:
-	creds = credentials.Credentials()
-	creds.parse_file(opts.authentication_file)
-else:
-	creds = credopts.get_credentials(lp)
+creds = credopts.get_credentials(lp)
 
 configRegistry = config_registry.ConfigRegistry()
 configRegistry.load()
